@@ -24,7 +24,7 @@ typedef struct sx_radix_node {
 	unsigned int isAggregate:1;
 	unsigned int aggregateLow;
 	unsigned int aggregateHi;
-	struct sx_prefix prefix;
+	struct sx_prefix *prefix;
 } sx_radix_node_t;
 
 typedef struct sx_radix_tree { 
@@ -43,6 +43,7 @@ struct sx_radix_node* sx_radix_tree_lookup_exact(struct sx_radix_tree* tree,
 
 struct sx_prefix* sx_prefix_alloc(struct sx_prefix* p);
 void sx_prefix_destroy(struct sx_prefix* p);
+void sx_radix_node_destroy(struct sx_radix_node* p);
 void sx_prefix_adjust_masklen(struct sx_prefix* p);
 struct sx_prefix* sx_prefix_new(int af, char* text);
 int sx_prefix_parse(struct sx_prefix* p, int af, char* text);
@@ -50,8 +51,9 @@ int sx_prefix_range_parse(struct sx_radix_tree* t, int af, int ml, char* text);
 int sx_prefix_fprint(FILE* f, struct sx_prefix* p);
 int sx_prefix_snprintf(struct sx_prefix* p, char* rbuffer, int srb);
 int sx_prefix_snprintf_sep(struct sx_prefix* p, char* rbuffer, int srb, char*);
-int sx_prefix_snprintf_fmt(struct sx_prefix* p, char* rbuffer, int srb,
-	const char* name, const char* fmt);
+void sx_prefix_snprintf_fmt(struct sx_prefix* p, FILE* f,
+	const char* name, const char* fmt,
+	unsigned int aggregateLow, unsigned int aggregateHi);
 int sx_prefix_jsnprintf(struct sx_prefix* p, char* rbuffer, int srb);
 struct sx_radix_tree* sx_radix_tree_new(int af);
 struct sx_radix_node* sx_radix_node_new(struct sx_prefix* prefix);
@@ -65,7 +67,6 @@ int sx_radix_tree_foreach(struct sx_radix_tree* tree,
 int sx_radix_tree_aggregate(struct sx_radix_tree* tree);
 int sx_radix_tree_refine(struct sx_radix_tree* tree, unsigned refine);
 int sx_radix_tree_refineLow(struct sx_radix_tree* tree, unsigned refineLow);
-int sx_radix_tree_hyperaggregate(struct sx_radix_tree* tree);
 
 #ifndef HAVE_STRLCPY
 size_t strlcpy(char* dst, const char* src, size_t size);
